==> upload-api-client-internal-1.126.0.tgz: package/src/services/ApiKeysService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { ApiKey } from "../models/ApiKey";
import type { ApiKeyDetails } from "../models/ApiKeyDetails";
import type { ApiKeyType } from "../models/ApiKeyType";
import type { CreateApiKey } from "../models/CreateApiKey";
import type { DeleteApiKeyBatch } from "../models/DeleteApiKeyBatch";
import { request as __request } from "../core/request";

export class ApiKeysService {
  /**
   * Creates a new public or secret API key for the account.
   * @param accountId
   * @param apiKeyType
   * @param requestBody
   * @returns ApiKeyDetails Success.
   * @throws ApiError
   */
  public static async createApiKey(
    accountId: AccountId,
    apiKeyType: ApiKeyType,
    requestBody: CreateApiKey
  ): Promise<ApiKeyDetails> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/security/api_keys/${apiKeyType}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes an API key from an account.
   * @param accountId
   * @param apiKey
   * @returns void
   * @throws ApiError
   */
  public static async deleteApiKey(accountId: AccountId, apiKey: ApiKey): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/security/api_keys/${apiKey}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes multiple API keys from an account.
   * @param accountId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async deleteApiKeyBatch(accountId: AccountId, requestBody: DeleteApiKeyBatch): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/security/api_keys`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}

==> upload-api-client-internal-2.4.0.tgz: package/src/services/ApiKeysService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { ApiKeyDetails } from "../models/ApiKeyDetails";
import type { ApiKeyId } from "../models/ApiKeyId";
import type { ApiKeyType } from "../models/ApiKeyType";
import type { CreateApiKey } from "../models/CreateApiKey";
import type { DeleteApiKeyBatch } from "../models/DeleteApiKeyBatch";
import { request as __request } from "../core/request";

export class ApiKeysService {
  /**
   * Creates a new public or secret API key for the account.
   * @param accountId
   * @param apiKeyType
   * @param requestBody
   * @returns ApiKeyDetails Success.
   * @throws ApiError
   */
  public static async createApiKey(
    accountId: AccountId,
    apiKeyType: ApiKeyType,
    requestBody: CreateApiKey
  ): Promise<ApiKeyDetails> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/security/api_keys/${apiKeyType}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes an API key from an account.
   * @param accountId
   * @param apiKeyId
   * @returns void
   * @throws ApiError
   */
  public static async deleteApiKey(accountId: AccountId, apiKeyId: ApiKeyId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/security/api_keys/${apiKeyId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes multiple API keys from an account.
   * @param accountId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async deleteApiKeyBatch(accountId: AccountId, requestBody: DeleteApiKeyBatch): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/security/api_keys`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
